=================================================================================================
bisos.sites: Manages /bisos/var/sites/siteBpo and siteBpo/var symlink and umbrellas site services
=================================================================================================

.. contents::
   :depth: 3
..

Overview
========

bisos.capability is a python package for BISOS Capabilities Bundles –
Abstraction, Specification and Materialization.

Package Documentation At Github
===============================

The information below is a subset of the full of documentation for this
bisos-pip package. More complete documentation is available at:
https://github.com/bisos-pip/capability-cs

Realted Resources
=================

+--------------------------+------------------------------------------+
| bisos Capabilities Panel | file:/panels/capab                       |
|                          | ilities/_nodeBase_/fullUsagePanel-en.org |
+--------------------------+------------------------------------------+
|                          |                                          |
+--------------------------+------------------------------------------+

.. _table-of-contents:

Table of Contents TOC
=====================

-  `Overview <#overview>`__
-  `Package Documentation At
   Github <#package-documentation-at-github>`__
-  `Realted Resources <#realted-resources>`__
-  `Installation <#installation>`__

   -  `Installation With pip <#installation-with-pip>`__
   -  `Installation With pipx <#installation-with-pipx>`__

-  `Part of BISOS and ByStar — ByStar Internet Services Operating
   System <#part-of-bisos-and-bystar-----bystar-internet-services-operating-system>`__
-  `bisos.capability as a Standalone Piece of
   BISOS <#bisoscapability-as-a-standalone-piece-of-bisos>`__
-  `Documentation and Blee-Panels <#documentation-and-blee-panels>`__

   -  `bisos.capability Blee-Panels <#bisoscapability-blee-panels>`__

-  `Support <#support>`__

Installation
============

The sources for the bisos.capability pip package is maintained at:
https://github.com/bisos-pip/capability.

The bisos.capability pip package is available at PYPI as
https://pypi.org/project/bisos.capability

You can install bisos.capability with pip or pipx.

Installation With pip
---------------------

If you need access to bisos.capability as a python module, you can
install it with pip:

.. code:: bash

   pip install bisos.capability

Installation With pipx
----------------------

If you only need access to bisos.capability as a command on
command-line, you can install it with pipx:

.. code:: bash

   pipx install bisos.capability

The following commands are made available:

-  seedCapability.cs
-  exmpl-capability.cs

Part of BISOS and ByStar — ByStar Internet Services Operating System
====================================================================

| Layered on top of Debian, **BISOS**: (By\* Internet Services Operating
  System) is a unified and universal framework for developing both
  internet services and software-service continuums that use internet
  services. See `Bootstrapping ByStar, BISOS and
  Blee <https://github.com/bxGenesis/start>`__ for information about
  getting started with BISOS.
| **BISOS** is a foundation for **The Libre-Halaal ByStar Digital
  Ecosystem** which is described as a cure for losses of autonomy and
  privacy in a book titled: `Nature of
  Polyexistentials <https://github.com/bxplpc/120033>`__

*bisos.capability* is part of BISOS.

bisos.capability as a Standalone Piece of BISOS
===============================================

bisos.capability is a standalone piece of BISOS. It can be used as a
self-contained Python package separate from BISOS. Follow the
installation and usage instructions below for your own use.

Documentation and Blee-Panels
=============================

bisos.capability is part of ByStar Digital Ecosystem
http://www.by-star.net.

This module's primary documentation is in the form of Blee-Panels.
Additional information is also available in:
http://www.by-star.net/PLPC/180047

bisos.capability Blee-Panels
----------------------------

bisos.capability Blee-Panels are in ./panels directory. From within Blee
and BISOS these panels are accessible under the Blee "Panels" menu.

Support
=======

| For support, criticism, comments and questions; please contact the
  author/maintainer
| `Mohsen Banan <http://mohsen.1.banan.byname.net>`__ at:
  http://mohsen.1.banan.byname.net/contact
